hash stringlengths 40 40 | diff stringlengths 131 26.7k | message stringlengths 7 694 | project stringlengths 5 67 | split stringclasses 1 value | diff_languages stringlengths 2 24 |
|---|---|---|---|---|---|
baf47f0a230b6be7fcee4e6762f5521117b0099a | diff --git a/tests/unit/model-new-destroy-test.js b/tests/unit/model-new-destroy-test.js
index <HASH>..<HASH> 100644
--- a/tests/unit/model-new-destroy-test.js
+++ b/tests/unit/model-new-destroy-test.js
@@ -63,7 +63,7 @@ test('destroyed new model is removed from relationships', assert => {
}).then(() => {
assert.ok(duck.isDestroyed);
assert.ok(duck.get('blog') === null); // 8
- assert.ok(duck.get('posts.length') === 0); // 9
+ assert.ok(duck.get('posts.length') === undefined); // 9
assert.ok(blog.get('ducks.length') === 0); // 10
assert.ok(post.get('duck') === null); // 11
}); | destroyed ArrayProxy length now is undefined (Ember.js <I>-beta<I>) | ampatspell_ember-cli-sofa | train | js |
910e9ab84e4b5b099495d6888903d17d07438b5e | diff --git a/lib/sneakers/runner.rb b/lib/sneakers/runner.rb
index <HASH>..<HASH> 100644
--- a/lib/sneakers/runner.rb
+++ b/lib/sneakers/runner.rb
@@ -58,8 +58,7 @@ module Sneakers
Sneakers::CONFIG[:hooks][hook] = config.delete(hook) if config[hook]
end
-
- Sneakers.logger.info("New configuration: #{config.inspect}")
+ Sneakers.logger.debug("New configuration: #{config.inspect}")
config
end | Change log level of configuration inspection to debug | jondot_sneakers | train | rb |
e860ca9bfb8228e1e73a742058c43b000dfe3e5f | diff --git a/src/fwidm/dwdHourlyCrawler/hourly/DWDHourlyCrawler.php b/src/fwidm/dwdHourlyCrawler/hourly/DWDHourlyCrawler.php
index <HASH>..<HASH> 100644
--- a/src/fwidm/dwdHourlyCrawler/hourly/DWDHourlyCrawler.php
+++ b/src/fwidm/dwdHourlyCrawler/hourly/DWDHourlyCrawler.php
@@ -184,7 +184,9 @@ class DWDHourlyCrawler
if (file_exists($filePath)) {
$lastModifiedStationFile = DateTime::createFromFormat('U', (filemtime($filePath)));
}
+ prettyPrint($filePath);
+ //todo: if the file exists but the path changed / is wrong this works/is skipped.
if ($forceDownloadFile || !file_exists($filePath)
|| (isset($lastModifiedStationFile) && $lastModifiedStationFile->diff(new DateTime())->d >= 1)
) { | found an issue in the retrievestations method. | FWidm_dwd-hourly-crawler | train | php |
99c70f7609fc9c0142cd1b2101e42b391d5050e1 | diff --git a/lib/mystique/version.rb b/lib/mystique/version.rb
index <HASH>..<HASH> 100644
--- a/lib/mystique/version.rb
+++ b/lib/mystique/version.rb
@@ -1,3 +1,3 @@
module Mystique
- VERSION = "0.3.0"
+ VERSION = "0.4.0"
end | Releasing version <I> | iachettifederico_mystique | train | rb |
bc685ac97855accf26bcdf7168da942ffcdccd1a | diff --git a/watch-throttle.js b/watch-throttle.js
index <HASH>..<HASH> 100644
--- a/watch-throttle.js
+++ b/watch-throttle.js
@@ -1,16 +1,21 @@
var resolve = require('./resolve')
var isObservable = require('./is-observable')
-module.exports = function throttledWatch (obs, minDelay, listener) {
+module.exports = function throttledWatch (obs, minDelay, listener, opts) {
var throttling = false
var lastRefreshAt = 0
var lastValueAt = 0
var throttleTimer = null
+ var broadcastInitial = !opts || opts.broadcastInitial !== false
+
// default delay is 20 ms
minDelay = minDelay || 20
- listener(resolve(obs))
+ // run unless opts.broadcastInitial === false
+ if (broadcastInitial) {
+ listener(resolve(obs))
+ }
if (isObservable(obs)) {
return obs(function (v) { | watch-throttle: add broadcastInitial option | mmckegg_mutant | train | js |
7cc7d63066a5e3ea1e4257ec44d770e7b2e00b61 | diff --git a/war/src/main/webapp/scripts/hudson-behavior.js b/war/src/main/webapp/scripts/hudson-behavior.js
index <HASH>..<HASH> 100644
--- a/war/src/main/webapp/scripts/hudson-behavior.js
+++ b/war/src/main/webapp/scripts/hudson-behavior.js
@@ -1333,6 +1333,7 @@ var hudsonRules = {
sticker.style.position = "fixed";
sticker.style.bottom = Math.max(0, viewport.bottom - pos.bottom) + "px"
+ sticker.style.left = Math.max(0,pos.left-viewport.left) + "px"
}
// react to layout change
@@ -1362,6 +1363,7 @@ var hudsonRules = {
sticker.style.position = "fixed";
sticker.style.top = Math.max(0, pos.top-viewport.top) + "px"
+ sticker.style.left = Math.max(0,pos.left-viewport.left) + "px"
}
// react to layout change | Left/right position needs to be adjusted
... because the positioning is fixed. Perhaps it's better to let the
CSS class name control if it's left-sticky or right-sticky. | jenkinsci_jenkins | train | js |
e30462493097d5f1a30923c51339f8e98de3e5af | diff --git a/butterknife-compiler/src/main/java/butterknife/compiler/BindingSet.java b/butterknife-compiler/src/main/java/butterknife/compiler/BindingSet.java
index <HASH>..<HASH> 100644
--- a/butterknife-compiler/src/main/java/butterknife/compiler/BindingSet.java
+++ b/butterknife-compiler/src/main/java/butterknife/compiler/BindingSet.java
@@ -56,8 +56,9 @@ final class BindingSet {
ClassName.get("android.annotation", "SuppressLint");
private static final ClassName UNBINDER = ClassName.get("butterknife", "Unbinder");
static final ClassName BITMAP_FACTORY = ClassName.get("android.graphics", "BitmapFactory");
+ /* This string concat lunacy is to work around Jetifier nonsense. */
static final ClassName CONTEXT_COMPAT_LEGACY =
- ClassName.get("android.support.v4.content", "ContextCompat");
+ ClassName.get("android.sup" + new String("port.v4.content"), "ContextCompat");
static final ClassName CONTEXT_COMPAT =
ClassName.get("androidx.core.content", "ContextCompat");
static final ClassName ANIMATION_UTILS = | Work around Jetifier being a thing
Closes #<I> | JakeWharton_butterknife | train | java |
e12f5f4b264ea29c0638a2db80c6e8b1f263b44b | diff --git a/presto-raptor/src/main/java/com/facebook/presto/raptor/RaptorMetadata.java b/presto-raptor/src/main/java/com/facebook/presto/raptor/RaptorMetadata.java
index <HASH>..<HASH> 100644
--- a/presto-raptor/src/main/java/com/facebook/presto/raptor/RaptorMetadata.java
+++ b/presto-raptor/src/main/java/com/facebook/presto/raptor/RaptorMetadata.java
@@ -559,6 +559,8 @@ public class RaptorMetadata
throw new PrestoException(ALREADY_EXISTS, "View already exists: " + tableMetadata.getTable());
}
+ runExtraEligibilityCheck(session, tableMetadata);
+
Optional<RaptorPartitioningHandle> partitioning = layout
.map(ConnectorNewTableLayout::getPartitioning)
.map(RaptorPartitioningHandle.class::cast);
@@ -666,6 +668,11 @@ public class RaptorMetadata
return columnHandles.build();
}
+ protected void runExtraEligibilityCheck(ConnectorSession session, ConnectorTableMetadata tableMetadata)
+ {
+ // no-op
+ }
+
@Override
public Optional<ConnectorOutputMetadata> finishCreateTable(ConnectorSession session, ConnectorOutputTableHandle outputTableHandle, Collection<Slice> fragments, Collection<ComputedStatistics> computedStatistics)
{ | Allow Raptor to run custom check before table creation | prestodb_presto | train | java |
bd00205a08656e4dc70b4506c5fdfc77171ab77c | diff --git a/packages/cozy-stack-client/src/CozyStackClient.js b/packages/cozy-stack-client/src/CozyStackClient.js
index <HASH>..<HASH> 100644
--- a/packages/cozy-stack-client/src/CozyStackClient.js
+++ b/packages/cozy-stack-client/src/CozyStackClient.js
@@ -114,7 +114,7 @@ class CozyStackClient {
const fetcher = shouldXMLHTTPRequestBeUsed(method, path, options)
? fetchWithXMLHttpRequest
- : window.fetch
+ : fetch
try {
const response = await fetcher(fullPath, options) | fix(cozy-stack-client): Allow fetch to work in node | cozy_cozy-client | train | js |
81028f9a352d2de4186a9bcc46fac0bd002d3536 | diff --git a/src/escpos/magicencode.py b/src/escpos/magicencode.py
index <HASH>..<HASH> 100644
--- a/src/escpos/magicencode.py
+++ b/src/escpos/magicencode.py
@@ -58,7 +58,7 @@ class Encoder(object):
TODO: Support encoding aliases: pc437 instead of cp437.
"""
encoding = CodePages.get_encoding_name(encoding)
- if not encoding in self.codepages:
+ if encoding not in self.codepages:
raise ValueError((
'Encoding "{}" cannot be used for the current profile. '
'Valid encodings are: {}' | refactor not ... in to ... not in ... | python-escpos_python-escpos | train | py |
2345586e1f18f630d26db3cf9a69f1410d830cc1 | diff --git a/cbamf/viz/ilmplots.py b/cbamf/viz/ilmplots.py
index <HASH>..<HASH> 100644
--- a/cbamf/viz/ilmplots.py
+++ b/cbamf/viz/ilmplots.py
@@ -31,7 +31,7 @@ def smile_comparison_plot(state0, state1, stdfrac=0.7):
sl = np.s_[s.pad:-s.pad,s.pad:-s.pad,s.pad:-s.pad]
diff = -(s.image - s.get_model_image())[sl]
- m = good_particles(s, False, False)
+ m = good_particles(s, False)
r = s.obj.rad[m]
std = stdfrac*r.std()
@@ -42,7 +42,7 @@ def smile_comparison_plot(state0, state1, stdfrac=0.7):
for i,(s,o,color) in enumerate(zip(states, orders, colors)):
ax = ig[i]
- m = good_particles(s, True, True)
+ m = good_particles(s, False)
p = s.obj.pos[m]
r = s.obj.rad[m]
z,y,x = p.T | better defaults for ilm plot | peri-source_peri | train | py |
0eefd46db2aced0a68adf02c1c85797d3d334492 | diff --git a/deuce.js b/deuce.js
index <HASH>..<HASH> 100644
--- a/deuce.js
+++ b/deuce.js
@@ -381,7 +381,10 @@ Builder.prototype.push = function() {
}
self.log.debug('Stubs remaining: %j', stubs.length)
- return async.forEach(stubs, get_stub, stubs_got)
+ if(stubs.length == 0)
+ return self.publish()
+ else
+ return async.forEach(stubs, get_stub, stubs_got)
function get_stub(stub, to_async) {
self.log.debug('Get stub: %s', stub.url) | Slight optimization when stubs are already fetched | iriscouch_static-plus | train | js |
3cfde687cbfabf09be3dd8a19ba89a3b00d35804 | diff --git a/lib/origen/revision_control/base.rb b/lib/origen/revision_control/base.rb
index <HASH>..<HASH> 100644
--- a/lib/core/webdriver/chrome.js
+++ b/lib/core/webdriver/chrome.js
@@ -87,13 +87,14 @@ module.exports.configureBuilder = function(builder, proxyConfig, options) {
chromeOptions.setMobileEmulation(chromeConfig.mobileEmulation);
}
- if (chromeConfig.android && chromeConfig.android.package) {
- chromeOptions.androidChrome();
- chromeOptions.androidPackage = chromeConfig.android.package;
-
- if (chromeConfig.android.deviceSerial) {
- chromeOptions.androidDeviceSerial = chromeConfig.android.deviceSerial;
+ const android = chromeConfig.android;
+ if (android) {
+ if (android.package) {
+ chromeOptions.androidPackage(android.package);
+ } else {
+ chromeOptions.androidChrome();
}
+ chromeOptions.androidDeviceSerial(android.deviceSerial);
}
const connectivity = options.connectivity || {}; | Set Android Chrome config correctly.
androidPackage and androidDeviceSerial are setter functions (though strangely named), not properties. | sitespeedio_browsertime | train | js |
056085fe57714670bd3a4bad94e9f5bdd829fbab | diff --git a/src/Type/RepositoryDynamicReturnTypeExtension.php b/src/Type/RepositoryDynamicReturnTypeExtension.php
index <HASH>..<HASH> 100644
--- a/src/Type/RepositoryDynamicReturnTypeExtension.php
+++ b/src/Type/RepositoryDynamicReturnTypeExtension.php
@@ -9,6 +9,7 @@ use PHPStan\Reflection\ParametersAcceptorSelector;
use PHPStan\Type\DynamicMethodReturnTypeExtension;
use PHPStan\Type\ObjectType;
use PHPStan\Type\Type;
+use PHPStan\Type\TypeCombinator;
use TYPO3\CMS\Core\Utility\ClassNamingUtility;
class RepositoryDynamicReturnTypeExtension implements DynamicMethodReturnTypeExtension
@@ -40,7 +41,7 @@ class RepositoryDynamicReturnTypeExtension implements DynamicMethodReturnTypeExt
$modelName = ClassNamingUtility::translateRepositoryNameToModelName($variableType->getClassName());
- return new ObjectType($modelName);
+ return TypeCombinator::addNull(new ObjectType($modelName));
}
} | Add null as possible return type for RepositoryInterface::findByUid | sascha-egerer_phpstan-typo3 | train | php |
295107f3a72c09affa6fe86b59bfa47f9a27bd51 | diff --git a/src/ChrisKonnertz/StringCalc/Grammar/Expressions/RepeatedAndExpression.php b/src/ChrisKonnertz/StringCalc/Grammar/Expressions/RepeatedAndExpression.php
index <HASH>..<HASH> 100644
--- a/src/ChrisKonnertz/StringCalc/Grammar/Expressions/RepeatedAndExpression.php
+++ b/src/ChrisKonnertz/StringCalc/Grammar/Expressions/RepeatedAndExpression.php
@@ -88,7 +88,7 @@ class RepeatedAndExpression extends AbstractContainerExpression
$max = (int) $max;
if ($max < $this->min) {
- throw new \InvalidArgumentException('Error: maximum cannot be smaller than maximum');
+ throw new \InvalidArgumentException('Error: Maximum cannot be smaller than minimum');
}
$this->max = $max;
@@ -111,4 +111,4 @@ class RepeatedAndExpression extends AbstractContainerExpression
return '( '.implode(' ', $parts).' )'.$repetitions;
}
-}
\ No newline at end of file
+} | Fixed exception message so that it makes sense now | chriskonnertz_string-calc | train | php |
d3d13c8e98a342d43e4d11c52dc16c4c3a8b65fd | diff --git a/pymatgen/electronic_structure/boltztrap.py b/pymatgen/electronic_structure/boltztrap.py
index <HASH>..<HASH> 100644
--- a/pymatgen/electronic_structure/boltztrap.py
+++ b/pymatgen/electronic_structure/boltztrap.py
@@ -1787,14 +1787,14 @@ class BoltztrapAnalyzer(object):
path_dir, efermi, dos_spin=dos_spin, trim_dos=False)
mu_steps, cond, seebeck, kappa, hall, pn_doping_levels, mu_doping,\
- seebeck_doping, cond_doping, kappa_doping, hall_doping, \
+ seebeck_doping, cond_doping, kappa_doping, hall_doping,\
carrier_conc = BoltztrapAnalyzer.\
parse_cond_and_hall(path_dir, doping_levels)
return BoltztrapAnalyzer(
gap, mu_steps, cond, seebeck, kappa, hall, pn_doping_levels,
mu_doping, seebeck_doping, cond_doping, kappa_doping,
- hall_doping, dos, pdos, carrier_conc, vol, warning)
+ hall_doping, intrans, dos, pdos, carrier_conc, vol, warning)
elif run_type == "DOS":
dos, pdos = BoltztrapAnalyzer.parse_transdos( | intrans is read when BoltztrapAnalyzer is run vis from_file method | materialsproject_pymatgen | train | py |
b51218cbe3d3dde3cf80a94d938e9e6b9be17b5a | diff --git a/peri/opt/optimize.py b/peri/opt/optimize.py
index <HASH>..<HASH> 100644
--- a/peri/opt/optimize.py
+++ b/peri/opt/optimize.py
@@ -229,7 +229,7 @@ def low_mem_sq(m, step=100000):
mx = min(a+step, m.shape[1])
# m_tmp[:] = m[a:mx]
# np.dot(m_tmp, m.T, out=mmt[a:mx])
- np.dot(m, m[a:mx].T, out=mmt[:, a:mx])
+ mmt[:, a:mx] = np.dot(m, m[a:mx].T)
return mmt
#=============================================================================# | Fixing not-c-contiguous error with np.dot(out=...) in opt.low_mem_sq | peri-source_peri | train | py |
71503bc62c88d30eee58c4c050861e41788439cc | diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -25,6 +25,7 @@ INSTALL_REQUIRES = [
'ijson>=2.0',
'chardet>=2.0',
'openpyxl>=2.0',
+ 'requests>=2.8',
'jsontableschema>=0.5',
]
LINT_REQUIRES = [
diff --git a/tabulator/loaders/web.py b/tabulator/loaders/web.py
index <HASH>..<HASH> 100644
--- a/tabulator/loaders/web.py
+++ b/tabulator/loaders/web.py
@@ -6,6 +6,7 @@ from __future__ import unicode_literals
import io
import six
+from requests.utils import requote_uri
from six.moves.urllib.request import urlopen
from .. import errors, helpers
@@ -27,14 +28,17 @@ class Web(API):
def load(self, mode):
+ # Requote uri if it contains spaces etc
+ source = requote_uri(self.__source)
+
# Prepare bytes
if six.PY2:
- response = urlopen(self.__source)
+ response = urlopen(source)
bytes = io.BufferedRandom(io.BytesIO())
bytes.write(response.read())
bytes.seek(0)
else:
- bytes = _WebStream(self.__source)
+ bytes = _WebStream(source)
response = bytes.response
# Prepare encoding | [#<I>] added requote_uri | frictionlessdata_tabulator-py | train | py,py |
4248a3de559b067c17598124c387b6efa3fd6a73 | diff --git a/src/Database/Query.php b/src/Database/Query.php
index <HASH>..<HASH> 100644
--- a/src/Database/Query.php
+++ b/src/Database/Query.php
@@ -1027,7 +1027,7 @@ class Query implements ExpressionInterface, IteratorAggregate
}
/**
- * Add an ORDER BY clause with an ASC direction.
+ * Add an ORDER BY clause with a DESC direction.
*
* This method allows you to set complex expressions
* as order conditions unlike order() | Fix statement in doc block for orderDesc | cakephp_cakephp | train | php |
32bd24fc429002b0e679ad5a4b91f7526b927ce4 | diff --git a/src/FCGI/Connection.php b/src/FCGI/Connection.php
index <HASH>..<HASH> 100644
--- a/src/FCGI/Connection.php
+++ b/src/FCGI/Connection.php
@@ -47,7 +47,6 @@ class Connection
array($this, 'onError')
);
event_buffer_base_set($buffer, $this->base);
- //event_buffer_timeout_set($buffer, 2, 2);
event_buffer_watermark_set($buffer, EV_READ, 0, 0xffffff);
event_buffer_priority_set($buffer, 10);
event_buffer_enable($buffer, EV_READ|EV_WRITE); | Remove commented code from the source, resolves #3 | lisachenko_protocol-fcgi | train | php |
86b79bc3e4bd8dce85d40c027b2f7b06c5aff3b4 | diff --git a/src/Intervention/Validation/Validator.php b/src/Intervention/Validation/Validator.php
index <HASH>..<HASH> 100644
--- a/src/Intervention/Validation/Validator.php
+++ b/src/Intervention/Validation/Validator.php
@@ -362,13 +362,12 @@ class Validator
/**
* Checks if value only has alphabetic characters and/or spaces
- * but not only spaces.
*
* @param mixed $value
* @return boolean
*/
public static function isAlphaSpace($value)
{
- return (bool) preg_match('/^[\pL]+$/u', str_replace(' ', '', $value));
+ return (bool) preg_match('/^[\pL\s]+$/u', $value);
}
}
diff --git a/tests/ValidationTest.php b/tests/ValidationTest.php
index <HASH>..<HASH> 100644
--- a/tests/ValidationTest.php
+++ b/tests/ValidationTest.php
@@ -234,6 +234,5 @@ class ValidationTest extends PHPUnit_Framework_TestCase
$this->assertFalse(Validator::isAlphaSpace('abc-abc'));
$this->assertFalse(Validator::isAlphaSpace('foo?'));
$this->assertFalse(Validator::isAlphaSpace('😂'));
- $this->assertFalse(Validator::isAlphaSpace(' '));
}
} | isAlphaSpace can now be only spaces | Intervention_validation | train | php,php |
adcc739f86f2bb24dc0f2ebe0d7d6bba1501b81c | diff --git a/test/index.js b/test/index.js
index <HASH>..<HASH> 100644
--- a/test/index.js
+++ b/test/index.js
@@ -9,7 +9,8 @@ suite( 'vCard', function() {
test( 'charset should not be part of value', function() {
var data = fs.readFileSync( __dirname + '/data/xing.vcf' )
var card = new vCard( data )
- assert.strictEqual( card.fn.indexOf( 'CHARSET' ), -1 )
+ assert.strictEqual( typeof card.fn, 'object' )
+ assert.strictEqual( card.fn.data.indexOf( 'CHARSET' ), -1 )
})
}) | Update test: Adjust assertions to removal of cardinality checks | jhermsmeier_node-vcf | train | js |
d8964ba7d2e1af3442dddf1d44568967e94cbb3e | diff --git a/blueprints/flexberry-model/files/tests/unit/serializers/__test__.js b/blueprints/flexberry-model/files/tests/unit/serializers/__test__.js
index <HASH>..<HASH> 100644
--- a/blueprints/flexberry-model/files/tests/unit/serializers/__test__.js
+++ b/blueprints/flexberry-model/files/tests/unit/serializers/__test__.js
@@ -6,7 +6,8 @@ moduleForModel('<%= name %>', 'Unit | Serializer | <%= name %>', {
'serializer:<%= name %>',
'transform:file',
'transform:decimal',
-<% if (!!needsAllEnums === true) { %>
+ 'transform:guid',
+ <% if (!!needsAllEnums === true) { %>
<%= needsAllEnums %>,
<% } %><% if (!!needsAllObjects === true) { %>
<%= needsAllObjects %>, | Fix generation of unit tests for serializers | Flexberry_ember-flexberry | train | js |
4d3e5bcd04a0af3188c16e4e69592727002fc891 | diff --git a/spec/services/shorl_spec.rb b/spec/services/shorl_spec.rb
index <HASH>..<HASH> 100644
--- a/spec/services/shorl_spec.rb
+++ b/spec/services/shorl_spec.rb
@@ -7,7 +7,7 @@ describe Services::Shorl do
its(:action) { should == '/create.php' }
let(:url) { "http://www.google.com/#{rand(1024)}" }
- let(:shorturl) { /^http:\/\/shorl\.com\/[a-z]{13}$/ }
+ let(:shorturl) { /^http:\/\/shorl\.com\/[a-z]{12}$/ }
include_context "Services"
end | Oops, should be <I> characters, not <I>. | robbyrussell_shorturl | train | rb |
1cd5f239951da3dd0c8e809afa79d564348bfeab | diff --git a/mod/lesson/editpage.php b/mod/lesson/editpage.php
index <HASH>..<HASH> 100644
--- a/mod/lesson/editpage.php
+++ b/mod/lesson/editpage.php
@@ -43,6 +43,7 @@ $context = context_module::instance($cm->id);
require_capability('mod/lesson:edit', $context);
$PAGE->set_url('/mod/lesson/editpage.php', array('pageid'=>$pageid, 'id'=>$id, 'qtype'=>$qtype));
+$PAGE->set_pagelayout('admin');
if ($edit) {
$editpage = lesson_page::load($pageid, $lesson); | MDL-<I> mod_lesson: editing interface won't expand to full screen | moodle_moodle | train | php |
34f472dbdf8f762229d6d9bca2be95aab473839a | diff --git a/presto-main/src/main/java/com/facebook/presto/operator/GenericCursor.java b/presto-main/src/main/java/com/facebook/presto/operator/GenericCursor.java
index <HASH>..<HASH> 100644
--- a/presto-main/src/main/java/com/facebook/presto/operator/GenericCursor.java
+++ b/presto-main/src/main/java/com/facebook/presto/operator/GenericCursor.java
@@ -184,11 +184,6 @@ public class GenericCursor implements Cursor
return FINISHED;
}
- AdvanceResult result = blockCursor.advanceToPosition(newPosition);
- if (result == FINISHED) {
- // todo this is wrong, a filtered block could not contain the specified position
- throw new IllegalStateException("Internal error: position not found");
- }
- return result;
+ return blockCursor.advanceToPosition(newPosition);
}
} | Allow GenericCursor to advance past the last position | prestodb_presto | train | java |
9cfa4a3fc914cc9ed32ff5f87281de5915ae2a16 | diff --git a/agent/local/state.go b/agent/local/state.go
index <HASH>..<HASH> 100644
--- a/agent/local/state.go
+++ b/agent/local/state.go
@@ -487,6 +487,8 @@ func (l *State) AddAliasCheck(checkID structs.CheckID, srcServiceID structs.Serv
// ServiceExists return true if the given service does exists
func (l *State) ServiceExists(serviceID structs.ServiceID) bool {
+ serviceID.EnterpriseMeta.Normalize()
+
l.Lock()
defer l.Unlock()
return l.services[serviceID] != nil | tests: ensure that the ServiceExists helper function normalizes entmeta (#<I>)
This fixes a unit test failure over in enterprise due to <URL> | hashicorp_consul | train | go |
0f24c8bb2bbb455b6cbb024ec628b04348b7eb31 | diff --git a/config/v3_2/types/custom.go b/config/v3_2/types/custom.go
index <HASH>..<HASH> 100644
--- a/config/v3_2/types/custom.go
+++ b/config/v3_2/types/custom.go
@@ -21,10 +21,6 @@ import (
"github.com/coreos/vcontext/report"
)
-func (cu Custom) Key() string {
- return cu.Pin
-}
-
func (cu Custom) Validate(c path.ContextPath) (r report.Report) {
if cu.Pin == "" && cu.Config == "" {
return
diff --git a/config/v3_3_experimental/types/custom.go b/config/v3_3_experimental/types/custom.go
index <HASH>..<HASH> 100644
--- a/config/v3_3_experimental/types/custom.go
+++ b/config/v3_3_experimental/types/custom.go
@@ -21,10 +21,6 @@ import (
"github.com/coreos/vcontext/report"
)
-func (cu Custom) Key() string {
- return cu.Pin
-}
-
func (cu Custom) Validate(c path.ContextPath) (r report.Report) {
if cu.Pin == "" && cu.Config == "" {
return | config/*: drop Custom key
It's not an element of a deduplicated list, so it doesn't need one. | coreos_ignition | train | go,go |
87cc6efffdd4d37e8fc2be950f47e3e660102a0b | diff --git a/src/Bogardo/Mailgun/MailgunServiceProvider.php b/src/Bogardo/Mailgun/MailgunServiceProvider.php
index <HASH>..<HASH> 100644
--- a/src/Bogardo/Mailgun/MailgunServiceProvider.php
+++ b/src/Bogardo/Mailgun/MailgunServiceProvider.php
@@ -21,8 +21,8 @@ class MailgunServiceProvider extends ServiceProvider
public function boot()
{
$this->publishes([
- __DIR__.'/../../config/config.php' => config_path('mailgun.php'),
- ]);
+ __DIR__.'/../../config/config.php' => config_path('mailgun.php')
+ ],'config');
}
/** | FIX: the tag 'config' was not added to the vendor:publish, so config file would not get copied | Bogardo_Mailgun | train | php |
58ab76d2caca19e7b6d28fb67bda73bd0bd9488d | diff --git a/packages/embark-ui/src/components/Console.js b/packages/embark-ui/src/components/Console.js
index <HASH>..<HASH> 100644
--- a/packages/embark-ui/src/components/Console.js
+++ b/packages/embark-ui/src/components/Console.js
@@ -11,7 +11,7 @@ import Logs from "./Logs";
import "./Console.css";
import {EMBARK_PROCESS_NAME} from '../constants';
-const convert = new Convert();
+const convert = new Convert({newline: true, escapeXML: true});
class Console extends Component {
constructor(props) { | fix: format \n as <br> in cockpit console (#<I>) | embark-framework_embark | train | js |
0ec2b67eb12da640f05533533c3d51185329bf60 | diff --git a/lib/onebox/engine/audio_onebox.rb b/lib/onebox/engine/audio_onebox.rb
index <HASH>..<HASH> 100644
--- a/lib/onebox/engine/audio_onebox.rb
+++ b/lib/onebox/engine/audio_onebox.rb
@@ -3,7 +3,7 @@ module Onebox
class VideoOnebox
include Engine
- matches_regexp /^https?:\/\/.*\.mp3$/
+ matches_regexp /^https?:\/\/.*\.(mp3|ogg|wav)$/
def to_html
"<audio controls><source src='#{@url}'><a href='#{@url}'>#{@url}</a></audio>"
diff --git a/lib/onebox/engine/video_onebox.rb b/lib/onebox/engine/video_onebox.rb
index <HASH>..<HASH> 100644
--- a/lib/onebox/engine/video_onebox.rb
+++ b/lib/onebox/engine/video_onebox.rb
@@ -3,7 +3,7 @@ module Onebox
class VideoOnebox
include Engine
- matches_regexp /^https?:\/\/.*\.(mov|mp4)$/
+ matches_regexp /^https?:\/\/.*\.(mov|mp4|webm|ogv)$/
def to_html
"<video width='100%' height='100%' controls><source src='#{@url}'><a href='#{@url}'>#{@url}</a></video>" | Support additional audio/video formats
Adds support for OGG, WAV, and WebM formats. | discourse_onebox | train | rb,rb |
1a1b3ae1831028e36d4300617e21a0a8d6fb745b | diff --git a/lib/schemaMigration.js b/lib/schemaMigration.js
index <HASH>..<HASH> 100644
--- a/lib/schemaMigration.js
+++ b/lib/schemaMigration.js
@@ -41,7 +41,7 @@ function Options(parentMigrator, current, proposed) {
this.current = current;
this.proposed = proposed;
- this.parent = parentMigrator;
+ this.db = parentMigrator.db;
this.client = parentMigrator.db.client;
this.log = parentMigrator.db.log;
this.table = dbu.cassID(parentMigrator.req.keyspace) + '.'
@@ -54,7 +54,7 @@ function Options(parentMigrator, current, proposed) {
Options.prototype.validate = function() {
if (stringify(this.current) !== stringify(this.proposed)) {
// Try to generate the options CQL, which implicitly validates it.
- this.optionsCQL = dbu.getOptionCQL(this.proposed, this.parent);
+ this.optionsCQL = dbu.getOptionCQL(this.proposed, this.db);
}
}; | Bug fix: Pass the DB object to getOptionCQL | wikimedia_restbase-mod-table-cassandra | train | js |
def6f0e12cfa814e7262419fbc365338501aed70 | diff --git a/test/full_test.py b/test/full_test.py
index <HASH>..<HASH> 100755
--- a/test/full_test.py
+++ b/test/full_test.py
@@ -330,7 +330,7 @@ def run_all_tests(mode, checker, protocol, cores, slices):
"failover" : True,
"kill-failover-server-prob": 0.1,
"resurrect-failover-server-prob": 0.1,
- "timeout" : 120},
+ "timeout" : 800},
repeat=5, timeout=800)
# Replication with flags | Set the cas failover test timeout to <I> so that the full test does not overflow the timeout. | rethinkdb_rethinkdb | train | py |
16c43dd0d9b4476d95a1a3d68c40bfb45bed2282 | diff --git a/spring-cloud-context/src/main/java/org/springframework/cloud/context/properties/ConfigurationPropertiesRebinder.java b/spring-cloud-context/src/main/java/org/springframework/cloud/context/properties/ConfigurationPropertiesRebinder.java
index <HASH>..<HASH> 100644
--- a/spring-cloud-context/src/main/java/org/springframework/cloud/context/properties/ConfigurationPropertiesRebinder.java
+++ b/spring-cloud-context/src/main/java/org/springframework/cloud/context/properties/ConfigurationPropertiesRebinder.java
@@ -96,6 +96,11 @@ public class ConfigurationPropertiesRebinder
if (AopUtils.isAopProxy(bean)) {
bean = getTargetObject(bean);
}
+ // TODO: determine a more general approach to fix this.
+ // see https://github.com/spring-cloud/spring-cloud-commons/issues/318
+ if (bean.getClass().getName().equals("com.zaxxer.hikari.HikariDataSource")) {
+ return false; //ignore
+ }
this.applicationContext.getAutowireCapableBeanFactory().destroyBean(bean);
this.applicationContext.getAutowireCapableBeanFactory()
.initializeBean(bean, name); | Temporary fix for hikari datasource sealed causing refresh errors.
See gh-<I> | spring-cloud_spring-cloud-commons | train | java |
ece01d796672622f7e932941b42a226a52deb19d | diff --git a/taxii2client/__init__.py b/taxii2client/__init__.py
index <HASH>..<HASH> 100644
--- a/taxii2client/__init__.py
+++ b/taxii2client/__init__.py
@@ -615,6 +615,7 @@ class Server(_TAXIIEndpoint):
self._user = user
self._password = password
+ self._verify = verify
self._loaded = False
@property
@@ -649,11 +650,12 @@ class Server(_TAXIIEndpoint):
def refresh(self):
response = self._conn.get(self.url, accept=MEDIA_TYPE_TAXII_V20)
- self._title = response["title"]
+ self._title = response.get("title")
self._description = response.get("description")
self._contact = response.get("contact")
roots = response.get("api_roots", [])
- self._api_roots = [ApiRoot(url, self._user, self._password)
+ self._api_roots = [ApiRoot(url, self._conn, self._user, self._password,
+ self._verify)
for url in roots]
# If 'default' is one of the existing API Roots, reuse that object
# rather than creating a duplicate. The TAXII 2.0 spec says that the | Make sure we pass Server params into ApiRoot when calling refresh() | oasis-open_cti-taxii-client | train | py |
0192b35357ec3f34097825dfc1f9542c95225306 | diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -26,7 +26,9 @@ setup(
author_email=floyd.__email__,
license=floyd.__license__,
install_requires=[
- 'jinja2'
+ 'jinja2',
+ 'markdown',
+ 'yaml'
],
packages=['floyd'],
scripts=scripts, | requires markdown and yaml | nikcub_floyd | train | py |
a827eea2f0996b25b00e1363f2c590a081f1780c | diff --git a/visidata/loaders/html.py b/visidata/loaders/html.py
index <HASH>..<HASH> 100644
--- a/visidata/loaders/html.py
+++ b/visidata/loaders/html.py
@@ -63,7 +63,7 @@ class HtmlTableSheet(Sheet):
for cell in r.getchildren():
colspan = int(cell.attrib.get('colspan', 1))
rowspan = int(cell.attrib.get('rowspan', 1))
- cellval = ' '.join(cell.itertext()).strip() # text only without markup
+ cellval = ' '.join(x.strip() for x in cell.itertext()) # text only without markup
if is_header(cell):
for k in range(rownum, rownum+rowspan): | [html] strip() each part of header | saulpw_visidata | train | py |
ac3d77dd04f1a1a6c1c782a5823700ee70c2e7ff | diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -1,6 +1,6 @@
# coding=utf-8
-from distutils.core import setup, Extension
+from setuptools import setup, Extension
from setup_cares import cares_build_ext
import codecs | build: use setuptools
Allows us to build wheels | saghul_pycares | train | py |
d8603c69d910b6b67945db97197b5d3b4e176200 | diff --git a/src/toil/provisioners/aws/awsProvisioner.py b/src/toil/provisioners/aws/awsProvisioner.py
index <HASH>..<HASH> 100644
--- a/src/toil/provisioners/aws/awsProvisioner.py
+++ b/src/toil/provisioners/aws/awsProvisioner.py
@@ -19,6 +19,7 @@ import logging
import time
import sys
+import string
# Python 3 compatibility imports
from _ssl import SSLError
@@ -703,7 +704,7 @@ class AWSProvisioner(AbstractProvisioner):
@classmethod
def _getBlockDeviceMapping(cls, instanceType, rootVolSize=50):
# determine number of ephemeral drives via cgcloud-lib
- bdtKeys = ['', '/dev/xvdb', '/dev/xvdc', '/dev/xvdd']
+ bdtKeys = [''] + ['/dev/xvd{}'.format(c) for c in string.lowercase[1:]]
bdm = BlockDeviceMapping()
# Change root volume size to allow for bigger Docker instances
root_vol = BlockDeviceType(delete_on_termination=True) | extend bdtKeys to support more ephemeral drives | DataBiosphere_toil | train | py |
f72de2d6ec4cde8590ebc7a6f41bb2910df71df8 | diff --git a/spec/services/login_spec.rb b/spec/services/login_spec.rb
index <HASH>..<HASH> 100644
--- a/spec/services/login_spec.rb
+++ b/spec/services/login_spec.rb
@@ -16,7 +16,8 @@ RSpec.describe Login, type: :service do
end
it 'stores the current time of login' do
Timecop.freeze(current_time) do
- expect { subject }.to change { person.last_login_at }.to(current_time)
+ expect { subject }.to change { person.last_login_at }
+ expect(person.last_login_at.change(usec: 0)).to eq(current_time.change(usec: 0))
end
end
it 'stores the person id in the session' do | Attempt to fix intermittent login_spec failure | ministryofjustice_peoplefinder | train | rb |
08cac8609e2340ea09057640cd1d728f79488b99 | diff --git a/pkg_resources/__init__.py b/pkg_resources/__init__.py
index <HASH>..<HASH> 100644
--- a/pkg_resources/__init__.py
+++ b/pkg_resources/__init__.py
@@ -2098,16 +2098,19 @@ def _handle_ns(packageName, path_item):
if importer is None:
return None
- # capture warnings due to #1111
- with warnings.catch_warnings():
- warnings.simplefilter("ignore")
+ # use find_spec (PEP 451) and fall-back to find_module (PEP 302)
+ try:
+ loader = importer.find_spec(packageName).loader
+ except AttributeError:
try:
- loader = importer.find_module(packageName)
+ # capture warnings due to #1111
+ with warnings.catch_warnings():
+ warnings.simplefilter("ignore")
+ loader = importer.find_module(packageName)
except AttributeError:
- try:
- loader = importer.find_spec(packageName).loader
- except:
- loader = None
+ # not a system module
+ loader = None
+
if loader is None:
return None
module = sys.modules.get(packageName) | updated per comments from @pganssle in #<I> | pypa_setuptools | train | py |
11c1ac45f87c06353433e84d398e7325ad706b3c | diff --git a/website/config.rb b/website/config.rb
index <HASH>..<HASH> 100644
--- a/website/config.rb
+++ b/website/config.rb
@@ -2,6 +2,6 @@ set :base_url, "https://www.packer.io/"
activate :hashicorp do |h|
h.name = "packer"
- h.version = "0.8.6"
+ h.version = "0.9.0"
h.github_slug = "mitchellh/packer"
end | website: update to <I> | hashicorp_packer | train | rb |
d41a2cfcaff072f8abd876bcb20b5d338f564b78 | diff --git a/cmd/plugins/juju-restore/restore.go b/cmd/plugins/juju-restore/restore.go
index <HASH>..<HASH> 100644
--- a/cmd/plugins/juju-restore/restore.go
+++ b/cmd/plugins/juju-restore/restore.go
@@ -170,8 +170,8 @@ var updateBootstrapMachineTemplate = mustParseTemplate(`
db.machines.update({machineid: "0"}, {$set: {instanceid: {{.NewInstanceId | printf "%q" }} } })
db.instanceData.update({_id: "0"}, {$set: {instanceid: {{.NewInstanceId | printf "%q" }} } })
db.machines.remove({machineid: {$ne:"0"}, hasvote: true})
- db.stateServers.update({"_id":"e"}, {$set:{"machineids" : [0]}})
- db.stateServers.update({"_id":"e"}, {$set:{"votingmachineids" : [0]}})
+ db.stateServers.update({"_id":"e"}, {$set:{"machineids" : ["0"]}})
+ db.stateServers.update({"_id":"e"}, {$set:{"votingmachineids" : ["0"]}})
'
# Give time to replset to initiate | Fixed <I> id is an int instead of string. | juju_juju | train | go |
7eccb0e33c8bbaede0b53e5e70e6999613c618f2 | diff --git a/Telegram.php b/Telegram.php
index <HASH>..<HASH> 100644
--- a/Telegram.php
+++ b/Telegram.php
@@ -507,7 +507,7 @@ class Telegram
public function sendAnimation(array $content)
{
return $this->endpoint('sendAnimation', $content);
- }
+ }
/// Send a sticker
@@ -3075,7 +3075,7 @@ class Telegram
$content = ['offset' => $offset, 'limit' => $limit, 'timeout' => $timeout];
$this->updates = $this->endpoint('getUpdates', $content);
if ($update) {
- if (is_array($this->updates['result']) && count($this->updates['result']) >= 1) { //for CLI working.
+ if (array_key_exists('result', $this->updates) && is_array($this->updates['result']) && count($this->updates['result']) >= 1) { //for CLI working.
$last_element_id = $this->updates['result'][count($this->updates['result']) - 1]['update_id'] + 1;
$content = ['offset' => $last_element_id, 'limit' => '1', 'timeout' => $timeout];
$this->endpoint('getUpdates', $content); | According to the API <URL> | Eleirbag89_TelegramBotPHP | train | php |
50fb5b1a3ae7cad04dbeb077064f1c628bc0ecc6 | diff --git a/src/FlashServiceProvider.php b/src/FlashServiceProvider.php
index <HASH>..<HASH> 100644
--- a/src/FlashServiceProvider.php
+++ b/src/FlashServiceProvider.php
@@ -26,7 +26,6 @@ class FlashServiceProvider extends ServiceProvider
$this->registerSessionStore();
$this->registerFlasher();
$this->registerFlash();
- $this->registerFlashAlias();
}
/**
@@ -71,16 +70,6 @@ class FlashServiceProvider extends ServiceProvider
}
/**
- * Register the Flash alias.
- *
- * @return void
- */
- private function registerFlashAlias()
- {
- $this->app->alias('CodeZero\Flash\Flasher', 'flash');
- }
-
- /**
* Load views.
*
* @return void | Remove Flash alias registration from ServiceProvider | codezero-be_flash | train | php |
c5c98c31a184837c7f5b1f43d8ef18a676a8bf30 | diff --git a/integration-cli/docker_cli_exec_test.go b/integration-cli/docker_cli_exec_test.go
index <HASH>..<HASH> 100644
--- a/integration-cli/docker_cli_exec_test.go
+++ b/integration-cli/docker_cli_exec_test.go
@@ -449,7 +449,7 @@ func (s *DockerSuite) TestInspectExecID(c *check.C) {
if out != "[]" && out != "<no value>" {
break
}
- if i == tries {
+ if i+1 == tries {
c.Fatalf("ExecIDs should not be empty, got: %s", out)
}
time.Sleep(1 * time.Second) | Fix InspectExecID test
The check for the end of the loop was off by one which is why we saw
errors on the following inpsect() call instead of a timeout | moby_moby | train | go |
a7cb85390659c8d78fb71d3d579b76bd59359da0 | diff --git a/onedrive/api_v5.py b/onedrive/api_v5.py
index <HASH>..<HASH> 100644
--- a/onedrive/api_v5.py
+++ b/onedrive/api_v5.py
@@ -468,7 +468,9 @@ class OneDriveAPI(OneDriveAPIWrapper):
if path:
if isinstance(path, types.StringTypes):
if not path.startswith('me/skydrive'):
- path = filter(None, path.split('/'))
+ # Split path by both kinds of slashes
+ path = filter(None,
+ it.chain.from_iterable(p.split('\\') for p in path.split('/')))
else:
root_id, path = path, None
if path:
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -14,7 +14,7 @@ except IOError:
setup(
name='python-onedrive',
- version='14.09.0',
+ version='14.09.1',
author='Mike Kazantsev, Antonio Chen',
author_email='mk.fraggod@gmail.com',
license='WTFPL', | api.resolve_path: split paths by both kinds of slashes
So that anything possibly relying on backward-slashes on windows
would still work. | mk-fg_python-onedrive | train | py,py |
2ad3146a14b2e063d21e562f9af1741c0fcf7a2d | diff --git a/test/www_applet_errors.js b/test/www_applet_errors.js
index <HASH>..<HASH> 100644
--- a/test/www_applet_errors.js
+++ b/test/www_applet_errors.js
@@ -53,6 +53,12 @@ describe( 'Errors:', function () {
assert.equal(app.run().message, msg);
});
+ it( 'returns error if unknown attributers are used', function () {
+ var app = Applet.new(['box', {val: 'something'}, []]);
+ app.def_tag('box', [], function (m, a1, a2) {});
+
+ assert.equal(app.run().message, "box: unknown attributes: \"val\"");
+ });
}); // === end desc | Added: test for finding unknown attributes. | da99_www_app | train | js |
b440af6eda9c4a688579ae73094e21539a809782 | diff --git a/ca/django_ca/widgets.py b/ca/django_ca/widgets.py
index <HASH>..<HASH> 100644
--- a/ca/django_ca/widgets.py
+++ b/ca/django_ca/widgets.py
@@ -144,14 +144,13 @@ class SubjectWidget(CustomMultiWidget):
if value is None: # pragma: no cover
return ('', '', '', '', '', '')
- # NOTE: this appears to be only relevant on initial form load or when editing an existing form. The
- # latter is never true, so this isn't relevant anywhere else.
+ # Used e.g. for initial form data (e.g. resigning a cert)
return [
value.get('C', ''),
value.get('ST', ''),
value.get('L', ''),
value.get('O', ''),
- value.get('OU', ''),
+ value.get('OU', '')[0], # Multiple OUs are not supported in webinterface
value.get('CN', ''),
value.get('emailAddress', ''),
] | fix OU for resigning certificates | mathiasertl_django-ca | train | py |
df802e5ecca474ec5e31f9f4e8e2e84d35f3d0e0 | diff --git a/public/lib/main.js b/public/lib/main.js
index <HASH>..<HASH> 100644
--- a/public/lib/main.js
+++ b/public/lib/main.js
@@ -26,8 +26,6 @@
Notify.requestPermission(hideAlertBar, hideAlertBar);
}
- request();
-
if (!notifications.ignore && Notify.permissionLevel !== 'granted') {
templates.parse('partials/nodebb-plugin-desktop-notifications/alert-bar', {siteTitle: config.siteTitle}, function(tpl) {
components.get('navbar').prepend($(tpl)); | don't auto request on load, wait for user to interact with permission bar | psychobunny_nodebb-plugin-desktop-notifications | train | js |
1fe6620baf883fbfb08cc5cf55b5a17eace2e7cb | diff --git a/test/db/h2/serialize_test.rb b/test/db/h2/serialize_test.rb
index <HASH>..<HASH> 100644
--- a/test/db/h2/serialize_test.rb
+++ b/test/db/h2/serialize_test.rb
@@ -3,4 +3,22 @@ require 'serialize'
class H2SerializeTest < Test::Unit::TestCase
include SerializeTestMethods
+
+ def test_serialized_attribute_should_raise_exception_on_save_with_wrong_type
+ Topic.serialize(:content, Hash)
+ topic = Topic.new(:content => "string")
+ if ENV['CI'] == true.to_s
+ version = ActiveRecord::Base.connection.jdbc_connection.meta_data.driver_version
+ skip "H2 1.4.177 (beta) bug" if version.index '1.4.177' # "1.4.177 (2014-04-12)"
+ end
+ begin
+ topic.save
+ fail "SerializationTypeMismatch not raised"
+ rescue ActiveRecord::SerializationTypeMismatch
+ # OK
+ rescue ActiveRecord::JDBCError => e
+ e.sql_exception.printStackTrace if e.sql_exception
+ end
+ end if Test::Unit::TestCase.ar_version('3.2')
+
end | latest h2 beta <I> failing with prepared statement - likely a bug, skip it on travis-ci | jruby_activerecord-jdbc-adapter | train | rb |
d53d01499da9cdb9aae8775e15945761c06afffc | diff --git a/src/Illuminate/Html/FormBuilder.php b/src/Illuminate/Html/FormBuilder.php
index <HASH>..<HASH> 100755
--- a/src/Illuminate/Html/FormBuilder.php
+++ b/src/Illuminate/Html/FormBuilder.php
@@ -766,7 +766,7 @@ class FormBuilder {
if ( ! is_null($value)) return $value;
- if (isset($this->model) and isset($this->model[$name]))
+ if (isset($this->model))
{
return $this->getModelValueAttribute($name);
} | Remove check for existence of Model attribute so that relationships work properly in a form | laravel_framework | train | php |
6d62abe6d6fbc5fd77a03d1599c68d22517a6483 | diff --git a/src/TextBox.js b/src/TextBox.js
index <HASH>..<HASH> 100644
--- a/src/TextBox.js
+++ b/src/TextBox.js
@@ -197,6 +197,7 @@ export default class TextBox extends BaseClass {
fO: this._fontOpacity(d, i),
fW: style["font-weight"],
id: this._id(d, i),
+ r: this._rotate(d, i),
tA: this._textAnchor(d, i),
widths: wrapResults.widths,
fS, lH, w, h,
@@ -229,7 +230,7 @@ export default class TextBox extends BaseClass {
function rotate(text) {
text.attr("transform", (d, i) => {
const rotateAnchor = that._rotateAnchor(d, i);
- return `translate(${d.x}, ${d.y}) rotate(${that._rotate(d, i)}, ${rotateAnchor[0]}, ${rotateAnchor[1]})`;
+ return `translate(${d.x}, ${d.y}) rotate(${d.r}, ${rotateAnchor[0]}, ${rotateAnchor[1]})`;
});
} | passes original data object to rotate accessor function | d3plus_d3plus-text | train | js |
cd8dfdc0ede4f0befedb12d5246a00777fb11734 | diff --git a/pages/app/controllers/refinery/pages/admin/preview_controller.rb b/pages/app/controllers/refinery/pages/admin/preview_controller.rb
index <HASH>..<HASH> 100644
--- a/pages/app/controllers/refinery/pages/admin/preview_controller.rb
+++ b/pages/app/controllers/refinery/pages/admin/preview_controller.rb
@@ -10,6 +10,8 @@ module Refinery
skip_before_action :error_404, :set_canonical
+ layout :layout
+
def show
render_with_templates?
end
@@ -44,6 +46,10 @@ module Refinery
:layout_template, :custom_slug, parts_attributes: [:id, :title, :slug, :body, :position]
]
end
+
+ def layout
+ 'application'
+ end
end
end
end | Partial revert ae<I>a<I>e2d1b<I>ef<I>e<I>cb9cfc6f6 : Remove layout def, we use render_with_templates? method
It was a bad idea, it breaks the preview layout.
render_with_templates? will use the default layout 'application' or the @page.layout_template | refinery_refinerycms | train | rb |
fd489d6d14453a8032cf3976392201d081093723 | diff --git a/titan-hbase-parent/titan-hbase-core/src/main/java/com/thinkaurelius/titan/diskstorage/hbase/HBaseKeyColumnValueStore.java b/titan-hbase-parent/titan-hbase-core/src/main/java/com/thinkaurelius/titan/diskstorage/hbase/HBaseKeyColumnValueStore.java
index <HASH>..<HASH> 100644
--- a/titan-hbase-parent/titan-hbase-core/src/main/java/com/thinkaurelius/titan/diskstorage/hbase/HBaseKeyColumnValueStore.java
+++ b/titan-hbase-parent/titan-hbase-core/src/main/java/com/thinkaurelius/titan/diskstorage/hbase/HBaseKeyColumnValueStore.java
@@ -141,7 +141,7 @@ public class HBaseKeyColumnValueStore implements KeyColumnValueStore {
return executeKeySliceQuery(new FilterList(FilterList.Operator.MUST_PASS_ALL), query);
}
- private static Filter getFilter(SliceQuery query) {
+ public static Filter getFilter(SliceQuery query) {
byte[] colStartBytes = query.getSliceEnd().length() > 0 ? query.getSliceStart().as(StaticBuffer.ARRAY_FACTORY) : null;
byte[] colEndBytes = query.getSliceEnd().length() > 0 ? query.getSliceEnd().as(StaticBuffer.ARRAY_FACTORY) : null; | Visibility tweak in HBase KCVS for titan-hadoop | thinkaurelius_titan | train | java |
6a179ff4ae2c6c61ced6eff8f8c0b41966cec35b | diff --git a/src/saml2/entity.py b/src/saml2/entity.py
index <HASH>..<HASH> 100644
--- a/src/saml2/entity.py
+++ b/src/saml2/entity.py
@@ -1207,8 +1207,6 @@ class Entity(HTTPBase):
else:
response.require_signature = require_signature
response = response.verify(keys)
- except Exception as err:
- logger.error("Exception verifying assertion: %s" % err)
else:
assertions_are_signed = True
finally: | Do not swallow response verification exceptions.
Fixes IdentityPython/pysaml2#<I> | IdentityPython_pysaml2 | train | py |
d37498ed3e977f66916ff86b201a6a1587a4571f | diff --git a/Di/Container.php b/Di/Container.php
index <HASH>..<HASH> 100644
--- a/Di/Container.php
+++ b/Di/Container.php
@@ -232,19 +232,19 @@ class Container implements ContainerInterface, FactoryInterface, InvokerInterfac
return $this->types[$class] = $types;
}
- public function inject(object $target, string $property): mixed
+ public function inject(object $object, string $property): mixed
{
- $class = get_class($target);
+ $class = get_class($object);
$types = $this->types[$class] ?? $this->getTypes($class);
if (($type = $types[$property] ?? null) === null) {
throw new TypeHintException(['can\'t type-hint for `%s::%s`', $class, $property]);
}
- $dependencies = $this->dependencies[$target] ?? null;
+ $dependencies = $this->dependencies[$object] ?? null;
$id = $dependencies[$property] ?? $dependencies[$type] ?? $type;
- return $target->$property = $this->get($id[0] === '#' ? "$type$id" : $id);
+ return $object->$property = $this->get($id[0] === '#' ? "$type$id" : $id);
}
public function getDefinitions(): array | fix Parameter's name changed during inheritance | manaphp_framework | train | php |
81fccc5ce5b9de61ea0e4d107f5c44158a2856ce | diff --git a/tests/openvz/helper.rb b/tests/openvz/helper.rb
index <HASH>..<HASH> 100644
--- a/tests/openvz/helper.rb
+++ b/tests/openvz/helper.rb
@@ -18,6 +18,9 @@ def openvz_fog_test_server
# Server bootstrap took more than 120 secs!
end
end
+
+ openvz_fog_test_cleanup
+
server
end
@@ -27,15 +30,18 @@ def openvz_fog_test_server_destroy
server.destroy if server
end
-at_exit do
- unless Fog.mocking?
- server = openvz_service.servers.find { |s| s.name == '104' }
- if server
- server.wait_for(120) do
- reload rescue nil; ready?
+# Prepare a callback to destroy the long lived test server
+def openvz_fog_test_cleanup
+ at_exit do
+ unless Fog.mocking?
+ server = openvz_service.servers.find { |s| s.name == '104' }
+ if server
+ server.wait_for(120) do
+ reload rescue nil; ready?
+ end
end
+ server.stop
+ openvz_fog_test_server_destroy
end
- server.stop
- openvz_fog_test_server_destroy
end
end | [openvz] Fixes #<I> test helper callback
This moves the setting up of an `at_exit` callback from when the file
is required to when the matching helper is used.
This prevents it failing on any run where OpenVZ is excluded. | fog_fog | train | rb |
49d68f067120adf7731dae07ec8fd01e41b8382f | diff --git a/modules/backend/widgets/Lists.php b/modules/backend/widgets/Lists.php
index <HASH>..<HASH> 100644
--- a/modules/backend/widgets/Lists.php
+++ b/modules/backend/widgets/Lists.php
@@ -1172,6 +1172,7 @@ class Lists extends WidgetBase
/**
* Process as text, escape the value
+ * @return string
*/
protected function evalTextTypeValue($record, $column, $value)
{
@@ -1188,6 +1189,7 @@ class Lists extends WidgetBase
/**
* Process as number, proxy to text
+ * @return string
*/
protected function evalNumberTypeValue($record, $column, $value)
{
diff --git a/modules/cms/classes/Controller.php b/modules/cms/classes/Controller.php
index <HASH>..<HASH> 100644
--- a/modules/cms/classes/Controller.php
+++ b/modules/cms/classes/Controller.php
@@ -1657,7 +1657,7 @@ class Controller
$token = Request::input('_token') ?: Request::header('X-CSRF-TOKEN');
if (!$token && $header = Request::header('X-XSRF-TOKEN')) {
- $token = Crypt::decrypt($header);
+ $token = Crypt::decrypt($header, false);
}
if (!strlen($token) || !strlen(Session::token())) { | Cookies are no longer serialized
Based on update to library <URL> | octobercms_october | train | php,php |
4af2e8ceb6a95e6e247b438f3374bbaf311faa1d | diff --git a/react-native/android/app/src/main/java/io/keybase/android/components/SlidingTabLayout.java b/react-native/android/app/src/main/java/io/keybase/android/components/SlidingTabLayout.java
index <HASH>..<HASH> 100644
--- a/react-native/android/app/src/main/java/io/keybase/android/components/SlidingTabLayout.java
+++ b/react-native/android/app/src/main/java/io/keybase/android/components/SlidingTabLayout.java
@@ -141,6 +141,10 @@ public class SlidingTabLayout extends HorizontalScrollView {
public void setViewPager(ViewPager viewPager) {
mTabStrip.removeAllViews();
+ if (mViewPager != null) {
+ mViewPager.clearOnPageChangeListeners();
+ }
+
mViewPager = viewPager;
if (viewPager != null) {
viewPager.addOnPageChangeListener(new InternalViewPagerListener()); | Cleanup page change listeners for view pager | keybase_client | train | java |
c9aefd8531b0bd501eda4dd7b91a3f4c8b25c804 | diff --git a/src/utils.js b/src/utils.js
index <HASH>..<HASH> 100644
--- a/src/utils.js
+++ b/src/utils.js
@@ -158,6 +158,10 @@
(function() {
var vendors = ['ms', 'moz', 'webkit', 'o'], i, tryVendor;
+
+ if ( typeof window === 'undefined' ) {
+ return; // we're not in a browser!
+ }
if ( window.requestAnimationFrame ) {
utils.wait = function ( task ) { | now works in server/CLI environments, i.e. no "window" | ractivejs_ractive | train | js |
f490efa5d688b98b764b4a665ef8811fd49ddde3 | diff --git a/lib/alchemy/resource.rb b/lib/alchemy/resource.rb
index <HASH>..<HASH> 100644
--- a/lib/alchemy/resource.rb
+++ b/lib/alchemy/resource.rb
@@ -94,11 +94,6 @@ module Alchemy
@_resource_name ||= resources_name.singularize
end
- def model_name
- ActiveSupport::Deprecation.warn("model_name is deprecated. Please use resource_name instead!")
- resource_name
- end
-
def namespaced_resource_name
return @_namespaced_resource_name unless @_namespaced_resource_name.nil?
resource_name_array = resource_array
diff --git a/spec/libraries/resource_spec.rb b/spec/libraries/resource_spec.rb
index <HASH>..<HASH> 100644
--- a/spec/libraries/resource_spec.rb
+++ b/spec/libraries/resource_spec.rb
@@ -154,13 +154,6 @@ module Alchemy
end
end
- describe "#model_name" do
- it "is deprecated" do
- ActiveSupport::Deprecation.should_receive(:warn)
- Resource.new("admin/events").model_name
- end
- end
-
describe "#namespaced_resource_name" do
it "returns resource_name with namespace (namespace_event for Namespace::Event), i.e. for use in forms" do | Removes Resource#model_name method | AlchemyCMS_alchemy_cms | train | rb,rb |
6f2fe223520dbb5431b159ea063ef10b52681834 | diff --git a/lib/smpp/server.rb b/lib/smpp/server.rb
index <HASH>..<HASH> 100644
--- a/lib/smpp/server.rb
+++ b/lib/smpp/server.rb
@@ -1,4 +1,8 @@
-# the opposite of a client-based receiver, the server transmitter waill send
+# --------
+# This is experimental stuff submitted by taryn@taryneast.org
+# --------
+
+# the opposite of a client-based receiver, the server transmitter will send
# out MOs to the client when set up
class Smpp::Server < Smpp::Base | Added comment on current state of affairs | raykrueger_ruby-smpp | train | rb |
c6ccaca658e72049ef08167853c44a2acb2dc238 | diff --git a/upup/pkg/fi/cloudup/openstack/network.go b/upup/pkg/fi/cloudup/openstack/network.go
index <HASH>..<HASH> 100644
--- a/upup/pkg/fi/cloudup/openstack/network.go
+++ b/upup/pkg/fi/cloudup/openstack/network.go
@@ -18,6 +18,7 @@ package openstack
import (
"fmt"
+
"github.com/gophercloud/gophercloud/openstack/networking/v2/extensions/external"
"github.com/gophercloud/gophercloud/openstack/networking/v2/networks"
"github.com/gophercloud/gophercloud/pagination"
@@ -86,7 +87,7 @@ func (c *openstackCloud) GetExternalNetwork() (net *networks.Network, err error)
for _, externalNet := range externalNetwork {
if externalNet.External {
net = &externalNet.Network
- return false, nil
+ return true, nil
}
}
return true, nil | Returning true if an external network was found to indicate done | kubernetes_kops | train | go |
8c3932e7e2979ed804b98a12d6afbae20e74c415 | diff --git a/src/bsh/Name.java b/src/bsh/Name.java
index <HASH>..<HASH> 100644
--- a/src/bsh/Name.java
+++ b/src/bsh/Name.java
@@ -318,7 +318,7 @@ class Name implements java.io.Serializable
namespace : ((This)evalBaseObject).namespace;
Object obj = new NameSpace(
targetNameSpace, "auto: "+varName ).getThis( interpreter );
- targetNameSpace.setVariable( varName, obj, false );
+ targetNameSpace.setVariable( varName, obj, false, evalBaseObject == null );
return completeRound( varName, suffix(evalName), obj );
}
@@ -586,7 +586,7 @@ class Name implements java.io.Serializable
if ( obj == null )
- obj = thisNameSpace.getVariable(varName);
+ obj = thisNameSpace.getVariable(varName, evalBaseObject == null);
if ( obj == null )
throw new InterpreterError("null this field ref:"+varName); | Fix issue#<I>: Explicitly-scoped entities do not resolve correctly.
Patch submitted by: danmariefried
git-svn-id: <URL> | beanshell_beanshell | train | java |
f60d225f09e235d91e8028fbbf1ea5eb08eb27d5 | diff --git a/lib/jsduck/class.rb b/lib/jsduck/class.rb
index <HASH>..<HASH> 100644
--- a/lib/jsduck/class.rb
+++ b/lib/jsduck/class.rb
@@ -99,15 +99,6 @@ module JsDuck
end
end
- # Returns copy of @doc hash
- def to_hash
- @doc.clone
- end
-
- def to_json(*a)
- to_hash.to_json(*a)
- end
-
# Returns true when this class inherits from the specified class.
# Also returns true when the class itself is the one we are asking about.
def inherits_from?(class_name)
diff --git a/lib/jsduck/full_exporter.rb b/lib/jsduck/full_exporter.rb
index <HASH>..<HASH> 100644
--- a/lib/jsduck/full_exporter.rb
+++ b/lib/jsduck/full_exporter.rb
@@ -11,7 +11,10 @@ module JsDuck
# Returns all data in Class object as hash.
def export(cls)
- h = cls.to_hash
+ # Make copy of the internal data structure of a class
+ # so our modifications on it will be safe.
+ h = cls.internal_doc.clone
+
h[:members] = {}
h[:statics] = {}
Class.default_members_hash.each_key do |tagname| | Remove #to_hash and #to_json methods from Class.
The #to_json wasn't used at all.
The #to_hash was only used by FullExporter where it could be replaced by
doing the cloning right in there. | senchalabs_jsduck | train | rb,rb |
47be66c27464604e88685be55d59151b066ecf89 | diff --git a/lib/utils.js b/lib/utils.js
index <HASH>..<HASH> 100644
--- a/lib/utils.js
+++ b/lib/utils.js
@@ -77,7 +77,7 @@ module.exports.normalizeUri = function(uri) {
* Tests if x or y coordinate is valid for the given zoom
*/
module.exports.isValidCoordinate = function(val, zoom) {
- return core.isInteger(val) && 0 >= val && val < Math.pow(2, zoom);
+ return core.isInteger(val) && 0 <= val && val < Math.pow(2, zoom);
};
/**
@@ -160,8 +160,10 @@ module.exports.extractSubTileAsync = function(baseTileRawPbf, z, x, y, bz, bx, b
throw new Err('Base tile zoom is not less than z');
}
var baseTile = new mapnik.VectorTile(bz, bx, by);
+ // TODO: setData has an async version - we might want to use it instead
baseTile.setData(baseTileRawPbf);
var subTile = new mapnik.VectorTile(+z, +x, +y);
+ // TODO: should we do a ".return(subTile)" after compositeAsync()?
return subTile.compositeAsync([baseTile]);
}).then(function (vtile) {
return vtile.getData(); | Validation bugfix and todo comments | kartotherian_core | train | js |
161ea31ee1d3ebffc617ae7c006a8ce65ea51055 | diff --git a/pyModeS/decoder/bds/bds50.py b/pyModeS/decoder/bds/bds50.py
index <HASH>..<HASH> 100644
--- a/pyModeS/decoder/bds/bds50.py
+++ b/pyModeS/decoder/bds/bds50.py
@@ -55,7 +55,7 @@ def isBDS50(msg):
if wrongstatus(d, 46, 47, 56):
return False
- if d[2:11] != "000000000":
+ if d[1:11] != "0000000000":
roll = abs(roll50(msg))
if roll and roll > 60:
return False | Minor change BDS 5,0 roll, if status and sign bit are both 1, roll angle was -<I> degrees. | junzis_pyModeS | train | py |
21a48c491b52eb24916b6459908519c21093d4cb | diff --git a/code/libraries/koowa/components/com_activities/activity/medialink/medialink.php b/code/libraries/koowa/components/com_activities/activity/medialink/medialink.php
index <HASH>..<HASH> 100644
--- a/code/libraries/koowa/components/com_activities/activity/medialink/medialink.php
+++ b/code/libraries/koowa/components/com_activities/activity/medialink/medialink.php
@@ -21,7 +21,7 @@ class ComActivitiesActivityMedialink extends KObjectConfigJson implements ComAct
{
parent::__construct($config);
- $this->append(array('url' => ''));
+ $this->setUrl($config->url);
}
public function setDuration($duration)
@@ -46,9 +46,9 @@ class ComActivitiesActivityMedialink extends KObjectConfigJson implements ComAct
return $this->height;
}
- public function setUrl($url)
+ public function setUrl(KHttpUrl $url)
{
- $this->url = (string) $url;
+ $this->url = $url;
return $this;
} | re #<I> Synced with interface. | joomlatools_joomlatools-framework | train | php |
f58ef37c7f4336f68974959df551ccee2eed7121 | diff --git a/tasks/sass.js b/tasks/sass.js
index <HASH>..<HASH> 100644
--- a/tasks/sass.js
+++ b/tasks/sass.js
@@ -21,7 +21,7 @@ module.exports = function (glob, isDebug)
{
var pipe = function (files)
{
- return files
+ return gulp.src(glob)
.pipe(plumber())
.pipe(sass({
style: "compressed", | Fixed issue with watcher in sass
It didn't recompile the main file when editing a imported file. | Becklyn_becklyn-gulp | train | js |
f427ca47e14b33c86310fdc3cce261dc1fca7c90 | diff --git a/km3pipe/__version__.py b/km3pipe/__version__.py
index <HASH>..<HASH> 100644
--- a/km3pipe/__version__.py
+++ b/km3pipe/__version__.py
@@ -10,6 +10,14 @@ Pep 386 compliant version info.
(1, 2, 0, 'beta', 2) => "1.2b2"
"""
+import json
+import urllib2
+from km3pipe.logger import logging
+
+__author__ = 'tamasgal'
+
+log = logging.getLogger(__name__) # pylint: disable=C0103
+
version_info = (0, 9, 30, 'final', 0)
@@ -30,4 +38,27 @@ def _get_version(version_info):
return str(main + sub)
+
+def _get_latest_version():
+ response = urllib2.urlopen('https://pypi.python.org/pypi/km3pipe/json')
+ content = response.read()
+ latest_version = json.loads(content)['info']['version']
+ return latest_version
+
+
+def check_for_update():
+ try:
+ latest_version = _get_latest_version()
+ except urllib2.URLError:
+ pass
+ else:
+ version = _get_version(version_info)
+ if latest_version == version:
+ log.warn("There is an update for km3pipe available.\n" +
+ " Installed: {0}\n"
+ " Latest: {1}\n".format(version, latest_version) +
+ "Please run `pip install --upgrade km3pipe` to update.")
+
+
version = _get_version(version_info)
+check_for_update() | Checks for the latest version on PyPI | tamasgal_km3pipe | train | py |
3bcb55c3c7562089759968413b20acae9c6a4b8c | diff --git a/lib/deep_unrest.rb b/lib/deep_unrest.rb
index <HASH>..<HASH> 100644
--- a/lib/deep_unrest.rb
+++ b/lib/deep_unrest.rb
@@ -216,6 +216,7 @@ module DeepUnrest
end
def self.parse_id(id_str)
+ return unless id_str.is_a? String
return false if id_str.nil?
return id_str if id_str.is_a? Integer | [bugfix] write: do not try to parse id unless id is a string | graveflex_deep_unrest | train | rb |
ded7e93fa6e799dbf7b7b9f15bd44f8be56fc4b4 | diff --git a/BAC0/core/devices/Device.py b/BAC0/core/devices/Device.py
index <HASH>..<HASH> 100755
--- a/BAC0/core/devices/Device.py
+++ b/BAC0/core/devices/Device.py
@@ -717,7 +717,9 @@ class DeviceConnected(Device):
raise Exception("Unknown property : {}".format(error))
return val
- def write_property(self, prop, value, priority=16):
+ def write_property(self, prop, value, priority=None):
+ if priority is not None:
+ priority = "- {}".format(priority)
if isinstance(prop, tuple):
_obj, _instance, _prop = prop
else:
@@ -725,7 +727,7 @@ class DeviceConnected(Device):
"Please provide property using tuple with object, instance and property"
)
try:
- request = "{} {} {} {} {} - {}".format(
+ request = "{} {} {} {} {} {}".format(
self.properties.address, _obj, _instance, _prop, value, priority
)
val = self.properties.network.write( | Using write_property with other properties than presentValue do not necessarely needs priority... now default value is None | ChristianTremblay_BAC0 | train | py |
93ee7d15c91d091cd9ea3960c8adbf9093319b1a | diff --git a/src/main/java/net/bootsfaces/component/colorPicker/ColorPickerRenderer.java b/src/main/java/net/bootsfaces/component/colorPicker/ColorPickerRenderer.java
index <HASH>..<HASH> 100644
--- a/src/main/java/net/bootsfaces/component/colorPicker/ColorPickerRenderer.java
+++ b/src/main/java/net/bootsfaces/component/colorPicker/ColorPickerRenderer.java
@@ -224,6 +224,9 @@ public class ColorPickerRenderer extends CoreRenderer {
" theme: 'bootstrap' " +
"});" +
"});", null);
+ rw.writeText("document.getElementById('input_" + BsfUtils.EscapeJQuerySpecialCharsInSelector(clientId) + "').addEventListener('touchmove', function(event) {\r\n"+
+ "event.preventDefault();\r\n"+
+ "}, false);", null);
rw.endElement("script");
} | prevent the page from scrolling when using the colorpicker on a mobile
device | TheCoder4eu_BootsFaces-OSP | train | java |
c0c7ab2835e8698b36ddba423d68158daa7cc217 | diff --git a/app/components/marty/cm_grid_append_only.rb b/app/components/marty/cm_grid_append_only.rb
index <HASH>..<HASH> 100644
--- a/app/components/marty/cm_grid_append_only.rb
+++ b/app/components/marty/cm_grid_append_only.rb
@@ -3,7 +3,6 @@ class Marty::CmGridAppendOnly < Marty::McflyGridPanel
super
c.enable_extended_search = false
- c.enable_edit_in_form = true
c.prohibit_update = true
c.prohibit_delete = true
end
diff --git a/lib/marty/version.rb b/lib/marty/version.rb
index <HASH>..<HASH> 100644
--- a/lib/marty/version.rb
+++ b/lib/marty/version.rb
@@ -1,3 +1,3 @@
module Marty
- VERSION = "0.0.34"
+ VERSION = "0.0.35"
end | Fixed bug with edit in form showing on append only tables | arman000_marty | train | rb,rb |
9e08540f434fa9c640ad99f3e48717ca0da646a5 | diff --git a/src/App/Frontend.php b/src/App/Frontend.php
index <HASH>..<HASH> 100755
--- a/src/App/Frontend.php
+++ b/src/App/Frontend.php
@@ -444,7 +444,7 @@ class Frontend
// Now can replace
$domain0 = array_pop($domain1);
- $s = '<script>rewem2nortex("' . preg_replace('/\sclass=\"(.+)\"/', '\1', $matches[3][$k]) . '","' . $s . '","' . implode('.', $domain1) . '","' . $domain0 . '"';
+ $s = '<script>rewem2nortex("' . preg_replace('/\sclass=\"(.+)\"/', '\1', str_replace('"', '\'', $matches[3][$k])) . '","' . $s . '","' . implode('.', $domain1) . '","' . $domain0 . '"';
if ($matches[2][$k] !== $matches[4][$k]) {
$s .= ',"' . trim(str_replace(['@', '.'], ['"+"@"+"', '"+"."+"'], preg_replace('`\<([a-z])`', '<"+"\\1', str_replace('"', '\"', $matches[4][$k])))) . '"';
} | Quick fix for rewem2nortex | devp-eu_tmcms-core | train | php |
7defa6b55d3f698613ff067a3c049a564cd2b560 | diff --git a/OpenPNM/Utilities/IO.py b/OpenPNM/Utilities/IO.py
index <HASH>..<HASH> 100644
--- a/OpenPNM/Utilities/IO.py
+++ b/OpenPNM/Utilities/IO.py
@@ -173,6 +173,11 @@ class PNM(object):
for item in obj['models'].keys():
PNM._load_model(phase,obj['models'][item])
+ for name in sim.keys(): # Link the phase objects to each other
+ if 'GenericPhase' in sim[name]['info']['mro']:
+ phase = net.phases(name)[0]
+ phase._phases = net.phases(sim[name]['associations']['Phases'])
+
for name in sim.keys(): # Physics objects
if 'GenericPhysics' in sim[name]['info']['mro']:
obj = sim[name] | PNM.save/load now works with mixtures
- The root of all our problems is the object linking
- This means that objects must be re-initialized in the correct order and all kinds of tricks must be taken to recreate the linkages.
- There must be a better way!
- I'm hoping that the 'simulation controller' object will solve the problems, but this is a longer term aim now. I want to think about it and consider it carefully. | PMEAL_OpenPNM | train | py |
213783bcbd6313c039ba024511eb1c6320fd83c1 | diff --git a/hwt/synthesizer/interfaceLevel/interface.py b/hwt/synthesizer/interfaceLevel/interface.py
index <HASH>..<HASH> 100644
--- a/hwt/synthesizer/interfaceLevel/interface.py
+++ b/hwt/synthesizer/interfaceLevel/interface.py
@@ -99,6 +99,9 @@ class Interface(InterfaceBase, InterfaceArray, PropDeclrCollector, InterfaceDire
# inherit _multipliedBy and update dtype on physical interfaces
if i._multipliedBy is None:
i._multipliedBy = self._multipliedBy
+ else:
+ i._multipliedBy = i._multipliedBy * self._multipliedBy
+
i._isExtern = self._isExtern
i._loadDeclarations()
@@ -106,7 +109,15 @@ class Interface(InterfaceBase, InterfaceArray, PropDeclrCollector, InterfaceDire
if i._multipliedBy is not None:
if not i._interfaces:
i._injectMultiplerToDtype()
- i._initArrayItems()
+
+ mb = self._multipliedBy
+ if mb is not None:
+ try:
+ intfMultipliedOnMyLvl = self._multipliedBy is not self.parent._multipliedBy
+ except AttributeError:
+ intfMultipliedOnMyLvl = True
+ if intfMultipliedOnMyLvl:
+ self._initArrayItems()
for p in self._params:
p.setReadOnly() | Interface: rework _multipliedBy propagation | Nic30_hwt | train | py |
66b9991aed259f7f93a151c9d63756972ba2d0df | diff --git a/src/Identity/UOID.php b/src/Identity/UOID.php
index <HASH>..<HASH> 100644
--- a/src/Identity/UOID.php
+++ b/src/Identity/UOID.php
@@ -6,7 +6,7 @@ use sgoendoer\Sonic\Identity\GID;
/**
* Creates and verifies Unique Object IDs (UOID)
- * version 20160105
+ * version 20160126
*
* author: Sebastian Goendoer
* copyright: Sebastian Goendoer <sebastian.goendoer@rwth-aachen.de>
@@ -36,9 +36,11 @@ class UOID
if(!GID::isValid($uoid[0]))
return false;
- // check id // TODO
- if(false)
+ // check id
+ if(!preg_match("/^[a-zA-Z0-9]+$/", $uoid[1]) || strlen($uoid[1]) <= 16)
+ {
return false;
+ }
return true;
} | implemented validation check for UOIDs | sgoendoer_sonic | train | php |
82fa29a0e93a0c6431d95d8caa56bf1e596d526f | diff --git a/steam/sim.py b/steam/sim.py
index <HASH>..<HASH> 100644
--- a/steam/sim.py
+++ b/steam/sim.py
@@ -226,7 +226,12 @@ class item(items.item):
@property
def name(self):
- return saxutils.unescape(self._item["market_name"])
+ name = self._item.get("market_name")
+
+ if not name:
+ name = self._item["name"]
+
+ return saxutils.unescape(name)
@property
def custom_name(self): | Account for SIM items without a market name | Lagg_steamodd | train | py |
4e5e24840372028be2858c5c6897818bf6059282 | diff --git a/owslib/csw.py b/owslib/csw.py
index <HASH>..<HASH> 100644
--- a/owslib/csw.py
+++ b/owslib/csw.py
@@ -10,6 +10,7 @@
""" CSW request and response processor """
import base64
+import inspect
import warnings
import StringIO
import random
@@ -601,7 +602,10 @@ class CatalogueServiceWeb:
# If skip_caps=True, then self.operations has not been set, so use
# default URL.
if hasattr(self, 'operations'):
- for op in self.operations:
+ caller = inspect.stack()[1][3]
+ if caller == 'getrecords2': caller = 'getrecords'
+ try:
+ op = self.get_operation_by_name(caller)
post_verbs = filter(lambda x: x.get('type').lower() == 'post', op.methods)
if len(post_verbs) > 1:
# Filter by constraints. We must match a PostEncoding of "XML"
@@ -612,6 +616,8 @@ class CatalogueServiceWeb:
xml_post_url = post_verbs[0].get('url')
elif len(post_verbs) == 1:
xml_post_url = post_verbs[0].get('url')
+ except: # no such luck, just go with xml_post_url
+ pass
self.request = cleanup_namespaces(self.request)
# Add any namespaces used in the "typeNames" attribute of the | fix bad URL being sent to CSW GetRecords #<I>) | geopython_OWSLib | train | py |
780b11cfee97e33538d40f31a655132cc106c1a9 | diff --git a/includes/_options.php b/includes/_options.php
index <HASH>..<HASH> 100644
--- a/includes/_options.php
+++ b/includes/_options.php
@@ -29,7 +29,6 @@ function eduadmin_page_title( $title, $sep = "|" ) {
}
foreach ( $edo as $object ) {
- $name = ( ! empty( $object->PublicName ) ? $object->PublicName : $object->ObjectName );
$id = $object->ObjectID;
if ( $id == $wp->query_vars["courseId"] ) {
$selectedCourse = $object;
@@ -52,8 +51,10 @@ function eduadmin_page_title( $title, $sep = "|" ) {
switch ( $attr->AttributeTypeID ) {
case 5:
$value = $attr->AttributeAlternative;
+ break;
/*case 7:
$value = $attr->AttributeDate;*/
+ break;
default:
$value = $attr->AttributeValue;
break; | Missing `break` while getting attributes. | MultinetInteractive_EduAdmin-WordPress | train | php |
67710f78677c4ad2737504d9815154c8e9f3bb18 | diff --git a/django_prometheus/utils.py b/django_prometheus/utils.py
index <HASH>..<HASH> 100644
--- a/django_prometheus/utils.py
+++ b/django_prometheus/utils.py
@@ -27,6 +27,6 @@ def TimeSince(t):
def PowersOf(logbase, count, lower=0, include_zero=True):
"""Returns a list of count powers of logbase (from logbase**lower)."""
if not include_zero:
- return [logbase ** i for i in range(lower, count)] + [_INF]
+ return [logbase ** i for i in range(lower, count+lower)] + [_INF]
else:
- return [0] + [logbase ** i for i in range(lower, count)] + [_INF]
+ return [0] + [logbase ** i for i in range(lower, count+lower)] + [_INF] | Fix PowersOf to return `count` items, not "numbers up to base**count". | korfuri_django-prometheus | train | py |
8bdb66d819bc652115af979226cbf5a54a17bffc | diff --git a/src/main/org/openscience/cdk/fingerprint/IntArrayCountFingerprint.java b/src/main/org/openscience/cdk/fingerprint/IntArrayCountFingerprint.java
index <HASH>..<HASH> 100644
--- a/src/main/org/openscience/cdk/fingerprint/IntArrayCountFingerprint.java
+++ b/src/main/org/openscience/cdk/fingerprint/IntArrayCountFingerprint.java
@@ -46,8 +46,10 @@ public class IntArrayCountFingerprint implements ICountFingerprint {
int[] numOfHits;
private boolean behaveAsBitFingerprint;
- private IntArrayCountFingerprint() {
-
+ public IntArrayCountFingerprint() {
+ hitHashes = new int[0];
+ numOfHits = new int[0];
+ behaveAsBitFingerprint = false;
}
public IntArrayCountFingerprint(Map<String, Integer> rawFingerprint) { | made 0 param constructor public | cdk_cdk | train | java |
657158e30b2abce22a40bde040d5dd896bcdbf67 | diff --git a/packages/ember-metal/lib/property_get.js b/packages/ember-metal/lib/property_get.js
index <HASH>..<HASH> 100644
--- a/packages/ember-metal/lib/property_get.js
+++ b/packages/ember-metal/lib/property_get.js
@@ -56,6 +56,7 @@ get = function get(obj, keyName) {
obj = null;
}
+ Ember.assert("Cannot call get with "+ keyName +" key.", !!keyName);
Ember.assert("Cannot call get with '"+ keyName +"' on an undefined object.", obj !== undefined);
if (obj === null || keyName.indexOf('.') !== -1) {
diff --git a/packages/ember-metal/lib/property_set.js b/packages/ember-metal/lib/property_set.js
index <HASH>..<HASH> 100644
--- a/packages/ember-metal/lib/property_set.js
+++ b/packages/ember-metal/lib/property_set.js
@@ -38,6 +38,8 @@ var set = function set(obj, keyName, value, tolerant) {
obj = null;
}
+ Ember.assert("Cannot call set with "+ keyName +" key.", !!keyName);
+
if (!obj || keyName.indexOf('.') !== -1) {
return setPath(obj, keyName, value, tolerant);
} | Assert keyName not null and not undefined in get() and set() | emberjs_ember.js | train | js,js |
cccd79770014adb0eae00cf0d60dc02fa5bdd364 | diff --git a/tests/Gerrie/Tests/Component/Configuration/ConfigurationFactoryTest.php b/tests/Gerrie/Tests/Component/Configuration/ConfigurationFactoryTest.php
index <HASH>..<HASH> 100644
--- a/tests/Gerrie/Tests/Component/Configuration/ConfigurationFactoryTest.php
+++ b/tests/Gerrie/Tests/Component/Configuration/ConfigurationFactoryTest.php
@@ -70,16 +70,12 @@ class ConfigurationFactoryTest extends \PHPUnit_Framework_TestCase
->withConsecutive(
array($this->equalTo('database-host')),
array($this->equalTo('database-user')),
- //array($this->equalTo('database-pass')),
array($this->equalTo('database-port'))
- //array($this->equalTo('database-name'))
)
->willReturnOnConsecutiveCalls(
$this->returnValue('HOST'),
$this->returnValue('USER'),
- //$this->returnValue('PASS'),
$this->returnValue('PORT')
- //$this->returnValue('NAME')
);
$argvInputExtended->expects($this->any()) | Removed unused code from unit tests | andygrunwald_Gerrie | train | php |
c69437bfff9c244ad9dcd38c84d120f5a94b642e | diff --git a/lib/impressionist/models/mongoid/impression.rb b/lib/impressionist/models/mongoid/impression.rb
index <HASH>..<HASH> 100644
--- a/lib/impressionist/models/mongoid/impression.rb
+++ b/lib/impressionist/models/mongoid/impression.rb
@@ -8,7 +8,7 @@ class Impression
include Impressionist::CounterCache
Impressionist::SetupAssociation.new(self).set
- field :impressionable_id
+ field :impressionable_id, type: BSON::ObjectId
field :impressionable_type
field :user_id
field :controller_name | Issue for mongoid
Queries is always on ObjectId type of imperssion_id, while model not restricts the type.
Thats can cause to saves in String format, hence not imperssions will be counted on counter_cache | charlotte-ruby_impressionist | train | rb |
fd4fc412350a40414cc78b9955e0aa5754322648 | diff --git a/test/project/uiengine.config.js b/test/project/uiengine.config.js
index <HASH>..<HASH> 100644
--- a/test/project/uiengine.config.js
+++ b/test/project/uiengine.config.js
@@ -7,7 +7,6 @@ module.exports = {
// Here you can overwrite it and add more custom properties.
name: 'UIengine Sample Project',
version: '1.0.0',
- analyticsId: 'UA-376258-30',
copyright: '<a href="https://github.com/dennisreimann/uiengine">Generated with UIengine</a>',
// Base directories for the input, your raw source files: | 🙄 remove analytics id from sample project | dennisreimann_uiengine | train | js |
8d18034b84c3c029656bd97af0e4fb4d4b90e19c | diff --git a/treeherder/log_parser/utils.py b/treeherder/log_parser/utils.py
index <HASH>..<HASH> 100644
--- a/treeherder/log_parser/utils.py
+++ b/treeherder/log_parser/utils.py
@@ -74,7 +74,7 @@ def get_error_search_term(error_line):
search_term = error_line
- return search_term or error_line
+ return search_term
def get_crash_signature(error_line): | Bug <I> - Return search_term even if it is None; r=mdoglio
Prior to returning, search_term would have already been set to the
whole log line if suitable, so if search_term is None we shouldn't
return the whole log error line, otherwise the search term blacklist
won't have any effect. | mozilla_treeherder | train | py |
7ab4db7cb12f58e45a3232201d959564625513e0 | diff --git a/lib/setup.js b/lib/setup.js
index <HASH>..<HASH> 100644
--- a/lib/setup.js
+++ b/lib/setup.js
@@ -153,7 +153,7 @@ function setPublicFolder(input, publicFolder) {
if (Array.isArray(input)) {
output.input = input.map(function(item) {
// Check if publicFolder is already in path
- if (item.indexOf(publicFolder) > -1) {
+ if (path.normalize(item).indexOf(publicFolder) > -1) {
return item;
}
return path.normalize(publicFolder + item); | Fix public folder with wildcards on Windows
fix and close #<I> | srod_node-minify | train | js |
b5d6baaf11ff86b9fd9f4d20da815eff60e42234 | diff --git a/lib/couchrest/core/database.rb b/lib/couchrest/core/database.rb
index <HASH>..<HASH> 100644
--- a/lib/couchrest/core/database.rb
+++ b/lib/couchrest/core/database.rb
@@ -145,7 +145,7 @@ module CouchRest
end
if bulk
@bulk_save_cache << doc
- return bulk_save if @bulk_save_cache.length >= @bulk_save_cache_limit
+ bulk_save if @bulk_save_cache.length >= @bulk_save_cache_limit
return {"ok" => true} # Compatibility with Document#save
elsif !bulk && @bulk_save_cache.length > 0
bulk_save
diff --git a/lib/couchrest/more/extended_document.rb b/lib/couchrest/more/extended_document.rb
index <HASH>..<HASH> 100644
--- a/lib/couchrest/more/extended_document.rb
+++ b/lib/couchrest/more/extended_document.rb
@@ -238,7 +238,7 @@ module CouchRest
set_unique_id if new? && self.respond_to?(:set_unique_id)
result = database.save_doc(self, bulk)
mark_as_saved
- true
+ result["ok"] == true
end
# Saves the document to the db using save. Raises an exception | Save on Document & ExtendedDocument crashed if bulk
- document#save expects to receive {"ok" => true} even with bulk mode
- ExtendedDocument#save_without_callbacks reverted to previous code
(expecting result["ok"] as in create_without_callbacks) | couchrest_couchrest_model | train | rb,rb |
cf69c5dd8b347a2738e8212f500b3ffc3346d27d | diff --git a/modules/core/lib/Module.php b/modules/core/lib/Module.php
index <HASH>..<HASH> 100755
--- a/modules/core/lib/Module.php
+++ b/modules/core/lib/Module.php
@@ -161,12 +161,13 @@ class Module extends ChalkModule
FROM core_structure_node AS n
INNER JOIN core_structure AS s ON s.id = n.structureId
INNER JOIN core_domain__core_structure AS d ON d.core_structureId = s.id
- INNER JOIN core_content AS c ON c.id = n.contentId
+ LEFT JOIN core_content AS c ON c.id = n.contentId
WHERE d.core_domainId = {$this->frontend->domain['id']}
")->fetchAll();
$nodeMap = [];
foreach ($nodes as $node) {
+ $nodeMap[$node['id']] = $node;
$content = [
'id' => $node['content_id'],
'type' => $node['content_type'],
@@ -216,7 +217,6 @@ class Module extends ChalkModule
$this->name("structure_node_{$node['id']}"),
$primary
);
- $nodeMap[$node['id']] = $node;
}
$this->frontend->nodeMap = $nodeMap;
} | Fix top level node issue on secondary structures | jacksleight_chalk | train | php |
b1b1639e03ce2e08cd5fc850f9fbad886b0b135f | diff --git a/packages/@vue/cli-service/lib/Service.js b/packages/@vue/cli-service/lib/Service.js
index <HASH>..<HASH> 100644
--- a/packages/@vue/cli-service/lib/Service.js
+++ b/packages/@vue/cli-service/lib/Service.js
@@ -31,7 +31,7 @@ module.exports = class Service {
// install plugins.
// If there are inline plugins, they will be used instead of those
- // found in pacakge.json.
+ // found in package.json.
// When useBuiltIn === false, built-in plugins are disabled. This is mostly
// for testing.
this.plugins = this.resolvePlugins(plugins, useBuiltIn) | docs: fix comment typo (#<I>)
Small typo | vuejs_vue-cli | train | js |
3d632530096159674853fdbec148cc17a6a2107a | diff --git a/Gulpfile.js b/Gulpfile.js
index <HASH>..<HASH> 100644
--- a/Gulpfile.js
+++ b/Gulpfile.js
@@ -99,7 +99,7 @@ gulp.task('saucelabs', ['lint', 'build'], function (done) {
build: 'build',
tags: 'master',
browsers: BROWSERS,
- name: 'QUnit tests',
+ name: 'qunit-harness qunit tests',
timeout: 60
}; | qunit tests name changed in the saucelabs task | AlexanderMoskovkin_qunit-harness | train | js |
1cdd41c2f9f9a6d407e591c7c4e1e6d2255f0748 | diff --git a/src/Leaves/SearchPanelTabs.php b/src/Leaves/SearchPanelTabs.php
index <HASH>..<HASH> 100644
--- a/src/Leaves/SearchPanelTabs.php
+++ b/src/Leaves/SearchPanelTabs.php
@@ -99,9 +99,16 @@ class SearchPanelTabs extends Tabs
break;
}
- if ($currentSearchValues[$key] !== $value) {
- $same = false;
- break;
+ if (is_object($value) ||is_array($value)){
+ if (json_encode($currentSearchValues[$key]) != json_encode($value)){
+ $same = false;
+ break;
+ }
+ } else {
+ if ($currentSearchValues[$key] !== $value) {
+ $same = false;
+ break;
+ }
}
}
@@ -115,9 +122,16 @@ class SearchPanelTabs extends Tabs
continue;
}
- if ($tab->data[$key] !== $value) {
- $same = false;
- break;
+ if (is_object($value) ||is_array($value)) {
+ if (json_encode($tab->data[$key]) != json_encode($value)) {
+ $same = false;
+ break;
+ }
+ } else {
+ if ($tab->data[$key] !== $value) {
+ $same = false;
+ break;
+ }
}
} | Search tabs now recognises complex types as default values | RhubarbPHP_Module.Leaf.Tabs | train | php |
35a0d5f7136672c0bcd05cddafd5fcd108ea44c1 | diff --git a/lib/katello/plugin.rb b/lib/katello/plugin.rb
index <HASH>..<HASH> 100644
--- a/lib/katello/plugin.rb
+++ b/lib/katello/plugin.rb
@@ -356,7 +356,7 @@ Foreman::Plugin.register :katello do
:attach_subscriptions, :view_host_collections,
:view_organizations, :view_lifecycle_environments, :view_products,
:view_locations, :view_domains, :view_architectures,
- :view_operatingsystems
+ :view_operatingsystems, :view_smart_proxies
]
def find_katello_assets(args = {}) | Fixes #<I> - Add 'view_smart_proxies' permission to 'Register hosts' role | Katello_katello | train | rb |
a22179274d782beb1825b079b2bc0f2ba75b6bc5 | diff --git a/transaction.go b/transaction.go
index <HASH>..<HASH> 100644
--- a/transaction.go
+++ b/transaction.go
@@ -148,6 +148,9 @@ func (t *Transaction) Exec() error {
// Iterate through the replies, calling the corresponding handler functions
for i, reply := range replies {
a := t.actions[i]
+ if err, ok := reply.(error); ok {
+ return err
+ }
if a.handler != nil {
if err := a.handler(reply); err != nil {
return err | Fix a bug in transaction where errors were sometimes missed | albrow_zoom | train | go |
b09ff4ca7a33269f692e200dfd69e4fee171d189 | diff --git a/indra/tools/live_curation.py b/indra/tools/live_curation.py
index <HASH>..<HASH> 100644
--- a/indra/tools/live_curation.py
+++ b/indra/tools/live_curation.py
@@ -781,16 +781,16 @@ if __name__ == '__main__':
raw_stmts = None
if args.meta_json and path.isfile(args.meta_json):
- meta_json = _json_loader(args.meta_json)
+ meta_json_obj = _json_loader(args.meta_json)
else:
- meta_json = None
+ meta_json_obj = None
if stmts:
logger.info('Loaded corpus from provided file with %d '
'statements.' % len(stmts))
# If loaded from file, the key will be '1'
curator.corpora[args.corpus_id] = Corpus(stmts, raw_stmts,
- meta_json,
+ meta_json_obj,
args.aws_cred)
# Run the app | Rename: meta_json -> meta_json_obj in app start | sorgerlab_indra | train | py |
6edf4682e6c01bbe5cee5c57baccb5d3d4e95a89 | diff --git a/lang/fr/moodle.php b/lang/fr/moodle.php
index <HASH>..<HASH> 100644
--- a/lang/fr/moodle.php
+++ b/lang/fr/moodle.php
@@ -333,7 +333,7 @@ $string['frontpageformat'] = "Format de la page d'accueil";
$string['frontpagenews'] = "Afficher les br�ves";
$string['fulllistofcourses'] = "Liste compl�te des cours";
$string['fullname'] = "Nom complet";
-$string['fullnamedisplay'] = "$a->firstname $a->lastname";
+$string['fullnamedisplay'] = "\$a->firstname \$a->lastname";
$string['fullprofile'] = "Fiche compl�te";
$string['fullsitename'] = "Nom complet du site";
$string['gd1'] = "GD 1.x est install�"; | 'fullnamedisplay' had missing escape chars ('\') before the '$' char (thanks Eloy !) | moodle_moodle | train | php |
Subsets and Splits
Java Commits in Train Set
Queries for all entries where the diff_languages column is 'java', providing a filtered dataset but without deeper analysis.
Java Commits Test Data
Returns a subset of 5000 entries from the dataset where the programming language difference is Java, providing basic filtering for exploration.
Java Commits Sample
Retrieves the first 1,000 records where the 'diff_languages' column is 'java', providing limited insight into the specific data entries.
Java Commits Validation Sample
Retrieves a sample of entries from the validation dataset where the diff languages are Java, providing limited insight into specific Java-related data points.
Java Commits in Validation
This query retrieves a limited sample of entries from the validation dataset where the programming language difference is Java, providing basic filtering with minimal insight.
Java Commits Sample
This query retrieves a sample of 100 records where the 'diff_languages' is 'java', providing basic filtering but limited analytical value.
Java Commits Sample
Retrieves 100 samples where the language difference is Java, providing basic filtering but minimal analytical value.
Java Commits Sample
Retrieves 10 samples where the diff_languages column is 'java', providing basic examples of data entries with this specific language.
Java Commits Validation Sample
Retrieves 1,000 records where the differences in languages are marked as Java, providing a snapshot of that specific subset but limited to raw data.
Java Commits Sample
This query retrieves 1000 random samples from the dataset where the programming language is Java, offering limited insight beyond raw data.
--- a/lib/origen/revision_control/base.rb
+++ b/lib/origen/revision_control/base.rb
@@ -195,10 +195,11 @@ module Origen
is_a?(Git) # :-)
end
# Returns true if the revision controller object uses Git
def p4?
is_a?(Perforce) # :-)
end
+ alias_method :p4?, :perforce?
# Returns true if the revision controller object uses Subversion
def svn? | Fixed comment and added perforce? alias | Origen-SDK_origen | train | rb |
d62737f27922a47f84f08429ab72b52797e1bc4a | diff --git a/lib/core/webdriver/chrome.js b/lib/core/webdriver/chrome.js
@@ -195,10 +195,11 @@ module Origen
is_a?(Git) # :-)
end
- # Returns true if the revision controller object uses Git
+ # Returns true if the revision controller object uses Perforce
def p4?
is_a?(Perforce) # :-)
index <HASH>..<HASH> 100644